diff --git a/subsys/bluetooth/mesh/pb_gatt_srv.c b/subsys/bluetooth/mesh/pb_gatt_srv.c
index 85b60cbe0fd..1324665e481 100644
--- a/subsys/bluetooth/mesh/pb_gatt_srv.c
+++ b/subsys/bluetooth/mesh/pb_gatt_srv.c
@@ -245,9 +245,13 @@ static size_t gatt_prov_adv_create(struct bt_data prov_sd[2])
 dev_name:
 #if defined(CONFIG_BT_MESH_PB_GATT_USE_DEVICE_NAME)
 	prov_sd[prov_sd_len].type = BT_DATA_NAME_COMPLETE;
+#if defined(CONFIG_BT_DEVICE_NAME_DYNAMIC)
+	prov_sd[prov_sd_len].data_len = strnlen(bt_get_name(), CONFIG_BT_DEVICE_NAME_MAX);
+	prov_sd[prov_sd_len].data = (uint8_t *)bt_get_name();
+#else
 	prov_sd[prov_sd_len].data_len = sizeof(CONFIG_BT_DEVICE_NAME) - 1;
 	prov_sd[prov_sd_len].data = CONFIG_BT_DEVICE_NAME;
-
+#endif
 	prov_sd_len += 1;
 #endif
 
diff --git a/subsys/bluetooth/mesh/proxy_srv.c b/subsys/bluetooth/mesh/proxy_srv.c
index c3b33035a3f..ae63336c641 100644
--- a/subsys/bluetooth/mesh/proxy_srv.c
+++ b/subsys/bluetooth/mesh/proxy_srv.c
@@ -483,7 +483,12 @@ static const struct bt_data net_id_ad[] = {
 	BT_DATA(BT_DATA_SVC_DATA16, proxy_svc_data, NET_ID_LEN),
 };
 
+#if defined(CONFIG_BT_DEVICE_NAME_DYNAMIC)
+/* Not const to allow for runtime updates */
+static struct bt_data sd[] = {
+#else
 static const struct bt_data sd[] = {
+#endif /* CONFIG_BT_DEVICE_NAME_DYNAMIC */
 #if defined(CONFIG_BT_MESH_PROXY_USE_DEVICE_NAME)
 	BT_DATA(BT_DATA_NAME_COMPLETE, CONFIG_BT_DEVICE_NAME, sizeof(CONFIG_BT_DEVICE_NAME) - 1),
 #endif
@@ -529,6 +534,11 @@ static int enc_id_adv(struct bt_mesh_subnet *sub, uint8_t type,
 	proxy_svc_data[2] = type;
 	memcpy(&proxy_svc_data[3], &hash[8], 8);
 
+#if defined(CONFIG_BT_DEVICE_NAME_DYNAMIC) && defined(CONFIG_BT_MESH_PROXY_USE_DEVICE_NAME)
+	sd[0].data = (uint8_t *)bt_get_name();
+	sd[0].data_len = strnlen(bt_get_name(), CONFIG_BT_DEVICE_NAME_MAX);
+#endif
+
 	err = bt_mesh_adv_gatt_start(
 		type == BT_MESH_ID_TYPE_PRIV_NET ? &slow_adv_param : &fast_adv_param,
 		duration, enc_id_ad, ARRAY_SIZE(enc_id_ad), sd, ARRAY_SIZE(sd));
@@ -615,6 +625,11 @@ static int net_id_adv(struct bt_mesh_subnet *sub, int32_t duration)
 
 	memcpy(proxy_svc_data + 3, sub->keys[SUBNET_KEY_TX_IDX(sub)].net_id, 8);
 
+#if defined(CONFIG_BT_DEVICE_NAME_DYNAMIC) && defined(CONFIG_BT_MESH_PROXY_USE_DEVICE_NAME)
+	sd[0].data = (uint8_t *)bt_get_name();
+	sd[0].data_len = strnlen(bt_get_name(), CONFIG_BT_DEVICE_NAME_MAX);
+#endif
+
 	err = bt_mesh_adv_gatt_start(&slow_adv_param, duration, net_id_ad,
 				     ARRAY_SIZE(net_id_ad), sd, ARRAY_SIZE(sd));
 	if (err) {
